Individual contributors to the source code
------------------------------------------
- Mario Lassnig <mario.lassnig@cern.ch>, 2012-2019
- Vincent Garonne <vgaronne@gmail.com>, 2012-2019
- Angelos Molfetas <Angelos.Molfetas@cern.ch>, 2012
- Martin Barisits <martin.barisits@cern.ch>, 2012-2019
- Thomas Beermann <thomas.beermann@cern.ch>, 2012-2019
- Ralph Vigne <ralph.vigne@cern.ch>, 2012-2016
- Graeme Stewart <graeme.andrew.stewart@cern.ch>, 2012
- Yun-Pin Sun <winter0128@gmail.com>, 2012-2013
- Cedric Serfon <cedric.serfon@cern.ch>, 2012-2020
- Luis Rodrigues <lfrodrigues@gmail.com>, 2013
- WeiJen Chang <e4523744@gmail.com>, 2013-2014
- Gancho Dimitrov <gancho.dimitrov@cern.ch>, 2013
- Wen Guan <wguan.icedew@gmail.com>, 2014-2017
- David Cameron <d.g.cameron@gmail.com>, 2014-2016
- Tomáš Kouba <tomas.kouba@cern.ch>, 2014-2015
- Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
- Evangelia Liotiri <evangelia.liotiri@cern.ch>, 2014-2015
- Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2014-2018
- Fernando López <fernando.e.lopez@gmail.com>, 2015-2016
- Sylvain Blunier <sylvain.blunier@cern.ch>, 2016
- Tomas Javurek <tomas.javurek@cern.ch>, 2016-2019
- Brian Bockelman <bbockelm@cse.unl.edu>, 2016-2018
- Tobias Wegner <twegner@cern.ch>, 2017-2019
- Frank Berghaus <frank.berghaus@cern.ch>, 2017
- Vitjan Zavrtanik <vitjan.zavrtanik@cern.ch>, 2017
- Stefan Prenner <stefan.prenner@cern.ch>, 2017-2018
- Nicolo Magini <Nicolo.Magini@cern.ch>, 2017-2018
- Oliver Freyermuth <o.freyermuth@googlemail.com>, 2017
- Eric Vaandering <ericvaandering@gmail.com>, 2018
- Dimitrios Christidis <dimitrios.christidis@cern.ch>, 2018-2019
- Igor Mandrichenko <ivm@fnal.gov>, 2018
- Shreyansh Khajanchi <shreyansh_k@live.com>, 2018
- Robert Illingworth <illingwo@fnal.gov>, 2018
- Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
- Gabriele Gaetano Fronzé <gabriele.fronze@to.infn.it>, 2018-2021
- James Perry <j.perry@epcc.ed.ac.uk>, 2019
- Vivek Nigam <viveknigam.nigam3@gmail.com>, 2019 - 2020
- Kaustubh Hiware <hiwarekaustubh@gmail.com>, 2019
- Florido Paganelli <florido.paganelli@hep.lu.se>, 2019
- Boris Bauermeister <Boris.Bauermeister@gmail.com> 2019
- Ruturaj Gujar <ruturaj.gujar23@gmail.com> 2019
- Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
- Aristeidis Fkiaras <aristeidis.fkiaras@cern.ch>, 2019
- Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
- Muhammad Aditya Hilmy <mhilmy@hey.com>, 2020
- Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
- Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
- Rob Barnsley <R.Barnsley@skatelescope.org>, 2020
- Alan Malta Rodrigues <alan.malta@cern.ch>, 2020
- Mayank Sharma <mayank.sharma@cern.ch>, 2020
- Ian Johnson, <ian.johnson@stfc.ac.uk>, 2021
- Radu Carpa <radu.carpa@cern.ch>, 2021
- Dhruv Sondhi <dhruvsondhi05@gmail.com>, 2021
- Simon Fayer <simon.fayer05@imperial.ac.uk>, 2021
- Ilija Vukotic <ivukotic@uchicago.edu>, 2020-2021
- David Población Criado <david.poblacion.criado@cern.ch>, 2021
- Nick Smith <nick.smith@cern.ch>, 2021
- Rizart Dona <rizart.dona@cern.ch>, 2021
- Rakshita Varadarajan <rakshitajps@gmail.com>, 2021
- Fabio Luchetti <fabio.luchetti@cern.ch>, 2021
- Stefan Piperov <stefan.piperov@cern.ch>, 2021
- Jensen Zhang <hack@jensen-zhang.site>, 2022

Organisations employing contributors
------------------------------------
- European Organisation for Nuclear Research (Switzerland)
- University of Oslo (Norway)
- University of Wisconsin Madison (USA)
- National University of La Plata (Argentina)
- Albert Ludwigs Universität Freiburg (Germany)
- University of Nebraska Lincoln (USA)
- Bergische Universität Wuppertal (Germany)
- University of Victoria (Canada)
- INFN e Universita Genova (Italy)
- University of Bonn (Germany)
- Fermi National Accelerator Laboratory (USA)
- Leopold-Franzens Universität Innsbruck (Austria)
- Academia Sinica (Taiwan)
- University of Edinburgh (UK)
- Birla Institute of Technology, Mesra (India)
- Indian Institute of Technology, Kharagpur (India)
- Stockholm University, Stockholm (Sweden)
- Dwarkadas J. Sanghvi College of Engineering (India)
- Science and Technology Facilities Council (UK)
- Brookhaven National Laboratory (USA)
- Institut Teknologi Bandung (Indonesia)
- Imperial College London (UK)
- University of Chicago (USA)
- Purdue University (USA)
